# mcp2210-python
An MCP2210 python driver.

You can install this package using `pip install mcp2210-python`.


Documentation can be found here: [https://jeremyherbert.github.io/mcp2210-python](https://jeremyherbert.github.io/mcp2210-python)
